@@ -126,14 +126,11 @@ const VTKStreamlit: React.FunctionComponent = () => {
         renderData.args["style"].height && 
         renderData.args["style"].height.includes('px')) {
           Streamlit.setFrameHeight(parseInt(renderData.args["style"].height.replace('px', '')))
+    } else {
+      Streamlit.setFrameHeight(HEIGHT)
     }
   }, [renderData])
 
-  // initial state of streamlit component
-  useEffect(() => {
-    Streamlit.setFrameHeight(HEIGHT)
-  }, [])
-
   const cssStyle = useMemo(() => {
     return renderData && typeof renderData.args["style"] !== 'undefined' ? 
       renderData.args["style"] : 
